====
Pyth
====

.. image:: https://gitlab.com/supersk-python/pyth/badges/master/pipeline.svg
   :target: https://gitlab.com/supersk-python/pyth/-/pipelines
   :alt: pipeline status
    
.. image:: https://gitlab.com/supersk-python/pyth/badges/master/coverage.svg
   :alt: coverage status
    
.. image:: https://badge.fury.io/py/supersk-pyth.svg
   :target:  https://pypi.org/project/supersk-pyth/
   :alt: pypi package
    
**PY**\thon **T**\emplate **H**\elper

This project aims at helping to generate output with `jinja2 <https://palletsprojects.com/p/jinja/>`_ templates.

It uses flat `csv <https://docs.python.org/3.6/library/csv.html>`_ file for input data.

TODO
====

* Add Command Line option for changing csv delimiter
* Add header validator
* Add format header validator
* Extension for using other data than csv format
* Optimize iterable data and rendered object with generator maybe
* Handle output writing with other location than current directory
* Create a new function for basedir and basename
* Handle output file override

